@@ -1055,7 +1055,7 @@ process_sasl2_request(#sasl2_authenticate{mechanism = Mech, initial_response = C
     State1 = State#{sasl_mech => Mech},
     Mechs = get_sasl_mechanisms(State1),
     UAId = case UA of
-	       #sasl2_user_agent{id = ID} when id /= <<>> ->
+	       #sasl2_user_agent{id = ID} when ID /= <<>> ->
 		   ID;
 	       _ ->
 		   undefined
@@ -1168,8 +1168,9 @@ process_bind2(#{sasl2_ua_id := UAId, user := User, server := Server} = State, El
 	#bind2_bind{tag = Tag, sub_els = SubEls} ->
 	    {Resource, SessionId} =
 	    case {Tag, UAId} of
-		{undefined, undefined} -> {<<>>, undefined};
-		{<<>>, undefined} -> {<<>>, undefined};
+		{undefined, _} -> {<<>>, undefined};
+		{_, undefined} -> {<<>>, undefined};
+		{<<>>, _} -> {<<>>, undefined};
 		_ ->
 		    Hash = crypto:hash(sha, <<"salt", User/binary, Server/binary, UAId/binary>>),
 		    B64Hash = base64:encode(Hash),
@@ -1186,7 +1187,7 @@ process_bind2(#{sasl2_ua_id := UAId, user := User, server := Server} = State, El
 		{ok, State1} ->
 		    {State2, _, ResultEls} =
 		    try callback(handle_bind2_inline, SubEls, State1)
-		    catch _:{?MODULE, undef} -> {State1, []}
+		    catch _:{?MODULE, undef} -> {State1, SubEls, []}
 		    end,
 		    {State2, [#bind2_bound{sub_els = ResultEls}]};
 		_ ->
